@@ -672,37 +672,30 @@ int     smtp_helo(SMTP_STATE *state)
 #ifdef USE_TLS
     if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE
 	&& (state->misc_flags & SMTP_MISC_FLAG_IN_STARTTLS) != 0) {
-	if (state->reqtls_level == SMTP_REQTLS_POLICY_ACT_ENFORCE) {
-	    if ((session->features & SMTP_FEATURE_REQTLS) != 0) {
-		if (state->tls_stats)
-		    smtp_tls_stat_decide_reqtls(state->tls_stats,
-						TLS_STAT_COMPLIANT,
-						TLS_STAT_ENF_FULL);
-	    } else {
-		if (state->tls_stats)
-		    smtp_tls_stat_decide_reqtls(state->tls_stats,
-						TLS_STAT_VIOLATION,
-						TLS_STAT_ENF_FULL);
-		return (smtp_misc_fail(state, SMTP_MISC_FAIL_DONT_CACHE
-				       | SMTP_MISC_FAIL_SOFT_NON_FINAL,
-				       DSN_BY_LOCAL_MTA,
-				       SMTP_RESP_FAKE(&fake, "5.7.30"),
-				       "REQUIRETLS Failure: sender "
-				       "requested REQUIRETLS, but no "
-				       "server was found that supports "
-				       "REQUIRETLS. The last attempted "
-				       "server was %s", session->namaddr));
-	    }
-	} else if ((session->features & SMTP_FEATURE_REQTLS) != 0) {
+	if ((session->features & SMTP_FEATURE_REQTLS) != 0) {
 	    if (state->tls_stats)
 		smtp_tls_stat_decide_reqtls(state->tls_stats,
-					    TLS_STAT_COMPLIANT,
-					    TLS_STAT_ENF_RELAXED);
+					    SMTP_TLS_STAT_NAME_REQTLS,
+					    TLS_STAT_COMPLIANT);
+	} else if (state->reqtls_level == SMTP_REQTLS_POLICY_ACT_ENFORCE) {
+	    if (state->tls_stats)
+		smtp_tls_stat_decide_reqtls(state->tls_stats,
+					    SMTP_TLS_STAT_NAME_REQTLS,
+					    TLS_STAT_VIOLATION);
+	    return (smtp_misc_fail(state, SMTP_MISC_FAIL_DONT_CACHE
+				   | SMTP_MISC_FAIL_SOFT_NON_FINAL,
+				   DSN_BY_LOCAL_MTA,
+				   SMTP_RESP_FAKE(&fake, "5.7.30"),
+				   "REQUIRETLS Failure: sender "
+				   "requested REQUIRETLS, but no "
+				   "server was found that supports "
+				   "REQUIRETLS. The last attempted "
+				   "server was %s", session->namaddr));
 	} else {
 	    if (state->tls_stats)
 		smtp_tls_stat_decide_reqtls(state->tls_stats,
-					    TLS_STAT_DISABLED,
-					    TLS_STAT_ENF_RELAXED);
+					    SMTP_TLS_STAT_NAME_NONE,
+					    TLS_STAT_COMPLIANT);
 	    msg_info("%s: REQUIRETLS Debug: sender requested REQUIRETLS, "
 		     "but REQUIRETLS support was not offered by host "
 		     "%s", request->queue_id, session->namaddr);
@@ -866,17 +859,15 @@ int     smtp_helo(SMTP_STATE *state)
 		if (TLS_REQUIRED_BY_REQTLS_POLICY(state->reqtls_level)) {
 		    if (state->tls_stats)
 			smtp_tls_stat_decide_reqtls(state->tls_stats,
-						    TLS_STAT_VIOLATION,
-						    state->reqtls_level == SMTP_REQTLS_POLICY_ACT_ENFORCE ?
-						    TLS_STAT_ENF_FULL :
-						    TLS_STAT_ENF_RELAXED);
+						  SMTP_TLS_STAT_NAME_REQTLS,
+						    TLS_STAT_VIOLATION);
 		}
-		if (TLS_REQUIRED_BY_SECURITY_LEVEL(state->tls->level))
+		if (TLS_REQUIRED_BY_SECURITY_LEVEL(state->tls->level)) {
 		    if (state->tls_stats)
 			smtp_tls_stat_decide_sec_level(state->tls_stats,
 						       state->tls->level,
-						       TLS_STAT_VIOLATION,
-						       TLS_STAT_ENF_FULL);
+						       TLS_STAT_VIOLATION);
+		}
 		/* Then, REQUIRETLS failure must take precedence over other. */
 		if (TLS_REQUIRED_BY_REQTLS_POLICY(state->reqtls_level)) {
 		    return (smtp_misc_fail(state, SMTP_MISC_FAIL_DONT_CACHE
@@ -923,17 +914,14 @@ int     smtp_helo(SMTP_STATE *state)
 		if (TLS_REQUIRED_BY_REQTLS_POLICY(state->reqtls_level)) {
 		    if (state->tls_stats)
 			smtp_tls_stat_decide_reqtls(state->tls_stats,
-						    TLS_STAT_VIOLATION,
-						    state->reqtls_level == SMTP_REQTLS_POLICY_ACT_ENFORCE ?
-						    TLS_STAT_ENF_FULL :
-						    TLS_STAT_ENF_RELAXED);
+						  SMTP_TLS_STAT_NAME_REQTLS,
+						    TLS_STAT_VIOLATION);
 		}
 		if (TLS_REQUIRED_BY_SECURITY_LEVEL(state->tls->level))
 		    if (state->tls_stats)
 			smtp_tls_stat_decide_sec_level(state->tls_stats,
 						       state->tls->level,
-						       TLS_STAT_VIOLATION,
-						       TLS_STAT_ENF_FULL);
+						       TLS_STAT_VIOLATION);
 		/* Then, REQUIRETLS failure must take precedence over other. */
 		if (TLS_REQUIRED_BY_REQTLS_POLICY(state->reqtls_level))
 		    return (smtp_misc_fail(state, SMTP_MISC_FAIL_DONT_CACHE
@@ -964,14 +952,8 @@ int     smtp_helo(SMTP_STATE *state)
 	}
 	/* Continue in plain-text mode. */
 	if (state->tls_stats) {
-	    if (state->tls->level == TLS_LEV_NONE) {
-		/* TODO(wietse) May be fall-back after TLS handshake failed. */
-		smtp_tls_stat_decide_sec_level(state->tls_stats, state->tls->level,
-				     TLS_STAT_COMPLIANT, TLS_STAT_ENF_FULL);
-	    } else {
-		smtp_tls_stat_decide_sec_level(state->tls_stats, state->tls->level,
-				   TLS_STAT_DISABLED, TLS_STAT_ENF_RELAXED);
-	    }
+	    smtp_tls_stat_decide_sec_level(state->tls_stats, TLS_LEV_NONE,
+					   TLS_STAT_COMPLIANT);
 	}
     }
 #endif
@@ -1304,8 +1286,7 @@ static int smtp_start_tls(SMTP_STATE *state)
 	    if (state->tls_stats)
 		smtp_tls_stat_decide_sec_level(state->tls_stats,
 					       session->tls_context->level,
-					       TLS_STAT_VIOLATION,
-					       TLS_STAT_ENF_FULL);
+					       TLS_STAT_VIOLATION);
 
 	    /*
 	     * When the sender requested REQUIRETLS, and REQUIRETLS is
@@ -1315,7 +1296,8 @@ static int smtp_start_tls(SMTP_STATE *state)
 	    if (state->reqtls_level == SMTP_REQTLS_POLICY_ACT_ENFORCE) {
 		if (state->tls_stats)
 		    smtp_tls_stat_decide_reqtls(state->tls_stats,
-				     TLS_STAT_VIOLATION, TLS_STAT_ENF_FULL);
+						SMTP_TLS_STAT_NAME_REQTLS,
+						TLS_STAT_VIOLATION);
 		return (smtp_misc_fail(state, SMTP_MISC_FAIL_DONT_CACHE
 				       | SMTP_MISC_FAIL_SOFT_NON_FINAL,
 				       DSN_BY_LOCAL_MTA,
@@ -1330,8 +1312,8 @@ static int smtp_start_tls(SMTP_STATE *state)
 	    } else if (state->reqtls_level > SMTP_REQTLS_POLICY_ACT_DISABLE) {
 		if (state->tls_stats)
 		    smtp_tls_stat_decide_reqtls(state->tls_stats,
-						TLS_STAT_COMPLIANT,
-						TLS_STAT_ENF_RELAXED);
+						SMTP_TLS_STAT_NAME_REQTLS,
+						TLS_STAT_COMPLIANT);
 	    }
 	    return (smtp_site_fail(state, DSN_BY_LOCAL_MTA,
 				   SMTP_RESP_FAKE(&fake, "4.7.5"),
@@ -1352,14 +1334,12 @@ static int smtp_start_tls(SMTP_STATE *state)
 #endif
 
     /*
-     * Report relaxed enforcement for the initial TLS level if it was
-     * degraded.
+     * Report relaxed enforcement if the initial TLS level was degraded.
      */
     if (state->tls_stats)
 	smtp_tls_stat_decide_sec_level(state->tls_stats,
-				       state->tls->level, TLS_STAT_COMPLIANT,
-			   session->tls_context->level < state->tls->level ?
-				  TLS_STAT_ENF_RELAXED : TLS_STAT_ENF_FULL);
+				       session->tls_context->level,
+				       TLS_STAT_COMPLIANT);
 
     /*
      * At this point we have to re-negotiate the "EHLO" to reget the
